@@ -1,7 +1,7 @@
 use std::cmp::Ordering;
 
-#[derive(Eq, Clone, Copy, Serialize, Deserialize, Debug/*, NifStruct*/)]
 // #[module = "Coord"]
+#[derive(Default, Eq, Clone, Copy, Serialize, Deserialize, Debug/*, NifStruct*/)]
 pub struct Coord {
     pub x: i32,
     pub y: i32,
@@ -19,6 +19,10 @@ impl Coord {
     }
   }
 
+  pub fn distance(&self, other: &Self) -> i32 {
+    (self.x - other.x).abs() + (self.y - other.y).abs()
+  }
+
   pub fn matches(&self, x: i32, y: i32) -> bool {
     self.x == x && self.y == y
   }
